# Credit
Much of `aiopath` is re-implemented from [`pathlib.py` ](https://github.com/python/cpython/blob/master/Lib/pathlib.py) via the CPython project.

Some async I/O is handled by the [`aiofile`](https://pypi.org/project/aiofile/) and [`aiofiles`](https://github.com/Tinche/aiofiles) projects.
